From 3431fc5987b182e0992e6815416738998ad6a370 Mon Sep 17 00:00:00 2001
From: Enji Cooper <yaneurabeya@gmail.com>
Date: Wed, 5 Jun 2024 20:56:48 -0700
Subject: [PATCH 3/3] smiGetNode: guard against a NULL pointer dereference

Check the results of `strtok(..)` before passing off the result to
the `findObjectBy*(..)` function family. This helps avoid potential
issues in the event the called functions do not defensively guard
against invalid input and `smiGetNode` is provided invalid input to
begin with.

Reported by:	Coverity
Signed-off-by: Enji Cooper <yaneurabeya@gmail.com>
---
 lib/smi.c | 10 ++++++----
 1 file changed, 6 insertions(+), 4 deletions(-)

diff --git a/lib/smi.c b/lib/smi.c
index e32d6951..cbb41bb0 100644
--- a/lib/smi.c
+++ b/lib/smi.c
@@ -1836,10 +1836,12 @@ SmiNode *smiGetNode(SmiModule *smiModulePtr, const char *node)
 	}
     } else {
 	p = strtok(node2, ". ");
-	if (modulePtr) {
-	    objectPtr = findObjectByModuleAndName(modulePtr, p);
-	} else {
-	    objectPtr = findObjectByName(p);
+	if (p) {
+	    if (modulePtr) {
+		objectPtr = findObjectByModuleAndName(modulePtr, p);
+	    } else {
+		objectPtr = findObjectByName(p);
+	    }
 	}
     }
     
-- 
2.45.1

